==> elgg-1.9.2.zip: elgg-1.9.2/mod/file/languages/es.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'file' => "Archivos",
	'file:user' => "Archvos de %s",
	'file:friends' => "Archivos de amigos",
	'file:all' => "Archvios de todo el sitio",
	'file:edit' => "Editar archivo",
	'file:more' => "Mover archivo",
	'file:list' => "Listar archivos",
	'file:group' => "Archivos de los Grupos",
	'file:gallery' => "vista de galer&iacute;a",
	'file:gallery_list' => "Galer&iacute;a o vista de lista",
	'file:num_files' => "N&uacute;mero de archivos a mostrar",
	'file:user:gallery'=>'Ver galer&iacute;a de %s',
	'file:upload' => "Subir un archivo",
	'file:replace' => 'Reemplazar los contenidos del archivo (deja en blanco para no cambiar el archivo)',
	'file:list:title' => "%s's %s %s",
	'file:title:friends' => "Amigos'",

	'file:add' => 'Subir un archivo',

	'file:file' => "Archivo",

	'file:list:list' => 'Cambiar a vista de lista',
	'file:list:gallery' => 'Cambiar a vista de galer&iacute;a',

	'file:types' => "Tipos de archivos subidos",

	'file:type:' => 'Archivos',
	'file:type:all' => "Todos los archivos",
	'file:type:video' => "Videos",
	'file:type:document' => "Documentos",
	'file:type:audio' => "Audio",
	'file:type:image' => "Im&aacute;genes",
	'file:type:general' => "General",

	'file:user:type:video' => "Videos de %s",
	'file:user:type:document' => "Documentos de %s",
	'file:user:type:audio' => "Arcvhidos de audio de %s",
	'file:user:type:image' => "Im&aacute;genes de %s",
	'file:user:type:general' => "Archivos de %s",

	'file:friends:type:video' => "Videos de tus amigos",
	'file:friends:type:document' => "Documentos de tus amigos",
	'file:friends:type:audio' => "Archivos de audio de tus amigos",
	'file:friends:type:image' => "Im&aacute;genes de tus amigos",
	'file:friends:type:general' => "Archivos de tus amigos",

	'file:widget' => "Widget de archivos",
	'file:widget:description' => "Showcase your latest files",

	'groups:enablefiles' => 'Habilitar Archivos para los Grupos',

	'file:delete:confirm' => "&iquest;Seguro que deseas borrar este archivo?",

	'file:upload_limit' => 'El tamaño máximo permitido por fichero son %s.',

	'file:tagcloud' => "Nube de etiquetas",

	'file:display:number' => "N&uacute;mero de archivos a mostrar",

	'river:create:object:file' => '%s ha subido el archivo %s',
	'river:comment:object:file' => '%s ha comentado el archivo %s',

	'item:object:file' => 'Archivo',

	'file:notify:summary' => 'Nuevo archivo llamado %s',
	'file:notify:subject' => 'Nuevo archivo: %s',
	'file:notify:body' =>
'%s subió un nuevo archivo: %s

%s

Ver y comentar en el archivo:
%s
',

	/**
	 * Status messages
	 */

	'file:saved' => "Tu archivo ha sido guardado exitosamente.",
	'file:deleted' => "Tu archivo fue borrado exitosamente.",

	/**
	 * Error messages
	 */

	'file:none' => "No hay archivos.",
	'file:uploadfailed' => "No se pudo guardar el archivo.",
	'file:downloadfailed' => "El archvo no est&aacute; disponible momentaneamente.",
	'file:deletefailed' => "El archivo no pudo ser borrado ahora.",
	'file:noaccess' => "No tienes permisos para modficar este archivo",
	'file:nofile' => "Debes seleccionar un archivo",
);

==> elgg-1.11.0.zip: elgg-1.11.0/mod/file/languages/es.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'file' => "Archivos",
	'file:user' => "Archivos de %s",
	'file:friends' => "Archivos de amigos",
	'file:all' => "Archivos de todo el sitio",
	'file:edit' => "Editar archivo",
	'file:more' => "Mover archivo",
	'file:list' => "Listar archivos",
	'file:group' => "Archivos de los Grupos",
	'file:gallery' => "vista de galer&iacute;a",
	'file:gallery_list' => "Galer&iacute;a o vista de lista",
	'file:num_files' => "N&uacute;mero de archivos a mostrar",
	'file:user:gallery'=>'Ver galer&iacute;a de %s',
	'file:upload' => "Subir un archivo",
	'file:replace' => 'Reemplazar los contenidos del archivo (deja en blanco para no cambiar el archivo)',
	'file:list:title' => "%s's %s %s",
	'file:title:friends' => "Amigos'",

	'file:add' => 'Subir un archivo',

	'file:file' => "Archivo",

	'file:list:list' => 'Cambiar a vista de lista',
	'file:list:gallery' => 'Cambiar a vista de galer&iacute;a',

	'file:types' => "Tipos de archivos subidos",

	'file:type:' => 'Archivos',
	'file:type:all' => "Todos los archivos",
	'file:type:video' => "Videos",
	'file:type:document' => "Documentos",
	'file:type:audio' => "Audio",
	'file:type:image' => "Im&aacute;genes",
	'file:type:general' => "General",

	'file:user:type:video' => "Videos de %s",
	'file:user:type:document' => "Documentos de %s",
	'file:user:type:audio' => "Archivos de audio de %s",
	'file:user:type:image' => "Im&aacute;genes de %s",
	'file:user:type:general' => "Archivos de %s",

	'file:friends:type:video' => "Videos de tus amigos",
	'file:friends:type:document' => "Documentos de tus amigos",
	'file:friends:type:audio' => "Archivos de audio de tus amigos",
	'file:friends:type:image' => "Im&aacute;genes de tus amigos",
	'file:friends:type:general' => "Archivos de tus amigos",

	'file:widget' => "Widget de archivos",
	'file:widget:description' => "Presenta tus últimos archivos",

	'groups:enablefiles' => 'Habilitar Archivos para los Grupos',

	'file:delete:confirm' => "&iquest;Seguro que deseas borrar este archivo?",

	'file:upload_limit' => 'El tamaño máximo permitido por fichero son %s.',

	'file:tagcloud' => "Nube de etiquetas",

	'file:display:number' => "N&uacute;mero de archivos a mostrar",

	'river:create:object:file' => '%s ha subido el archivo %s',
	'river:comment:object:file' => '%s ha comentado el archivo %s',

	'item:object:file' => 'Archivo',

	'file:notify:summary' => 'Nuevo archivo llamado %s',
	'file:notify:subject' => 'Nuevo archivo: %s',
	'file:notify:body' =>
'%s subió un nuevo archivo: %s

%s

Ver y comentar en el archivo:
%s
',

	/**
	 * Status messages
	 */

	'file:saved' => "Tu archivo ha sido guardado correctamente.",
	'file:deleted' => "Tu archivo fue borrado correctamente.",

	/**
	 * Error messages
	 */

	'file:none' => "No hay archivos.",
	'file:uploadfailed' => "No se pudo guardar el archivo.",
	'file:downloadfailed' => "El archivo no est&aacute; disponible momentáneamente.",
	'file:deletefailed' => "El archivo no pudo ser borrado ahora.",
	'file:noaccess' => "No tienes permisos para modficar este archivo",
	'file:nofile' => "Debes seleccionar un archivo",
);
